diff decoders/ogg.c @ 47:ea58bc3b15d7

Added init() and quit() methods.
author Ryan C. Gordon <icculus@icculus.org>
date Sat, 22 Sep 2001 14:41:38 +0000
parents 0fc0f91b1b84
children cd91e1857b42
line wrap: on
line diff
--- a/decoders/ogg.c	Sat Sep 22 14:41:10 2001 +0000
+++ b/decoders/ogg.c	Sat Sep 22 14:41:38 2001 +0000
@@ -49,7 +49,8 @@
 #error SOUND_SUPPORTS_OGG must be defined.
 #endif
 
-
+static int OGG_init(void);
+static void OGG_quit(void);
 static int OGG_open(Sound_Sample *sample, const char *ext);
 static void OGG_close(Sound_Sample *sample);
 static Uint32 OGG_read(Sound_Sample *sample);
@@ -63,12 +64,27 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    OGG_open,       /* open() method       */
-    OGG_close,      /* close() method       */
-    OGG_read        /* read() method       */
+    OGG_init,       /*  init() method */
+    OGG_quit,       /*  quit() method */
+    OGG_open,       /*  open() method */
+    OGG_close,      /* close() method */
+    OGG_read        /*  read() method */
 };
 
 
+static int OGG_init(void)
+{
+    return(1);  /* always succeeds. */
+} /* OGG_init */
+
+
+static void OGG_quit(void)
+{
+    /* it's a no-op. */
+} /* OGG_quit */
+
+
+
     /*
      * These are callbacks from vorbisfile that let them read data from
      *  a RWops...